@@ -15,5 +15,5 @@ class VariationByExposition:
 
     def __init__(self, dict_json: Dict[str, Any]):
         self.variation_key: str = dict_json.get("variationKey", "")
-        self.variation_id: Optional[int] = dict_json.get("variationId", "")
-        self.exposition: int = dict_json.get("exposition", "")
+        self.variation_id: Optional[int] = dict_json.get("variationId")
+        self.exposition: float = dict_json.get("exposition", 0.0)
